<?php

namespace Litecms\PackagePlan\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\PackagePlan\Models\PackagePlan;

class PackagePlanPolicy
{

    /**
     * Determine if the given user can view the package_plan.
     *
     * @param UserPolicy $user
     * @param PackagePlan $package_plan
     *
     * @return bool
     */
    public function view(UserPolicy $user, PackagePlan $package_plan)
    {
        if ($user->canDo('package_plan.package_plan.view') && $user->isAdmin()) {
            return true;
        }

        return $package_plan->user_id == user_id() && $package_plan->user_type == user_type();
    }

    /**
     * Determine if the given user can create a package_plan.
     *
     * @param UserPolicy $user
     * @param PackagePlan $package_plan
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('package_plan.package_plan.create');
    }

    /**
     * Determine if the given user can update the given package_plan.
     *
     * @param UserPolicy $user
     * @param PackagePlan $package_plan
     *
     * @return bool
     */
    public function update(UserPolicy $user, PackagePlan $package_plan)
    {
        if ($user->canDo('package_plan.package_plan.edit') && $user->isAdmin()) {
            return true;
        }

        return $package_plan->user_id == user_id() && $package_plan->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given package_plan.
     *
     * @param UserPolicy $user
     * @param PackagePlan $package_plan
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, PackagePlan $package_plan)
    {
        return $package_plan->user_id == user_id() && $package_plan->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given package_plan.
     *
     * @param UserPolicy $user
     * @param PackagePlan $package_plan
     *
     * @return bool
     */
    public function verify(UserPolicy $user, PackagePlan $package_plan)
    {
        if ($user->canDo('package_plan.package_plan.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given package_plan.
     *
     * @param UserPolicy $user
     * @param PackagePlan $package_plan
     *
     * @return bool
     */
    public function approve(UserPolicy $user, PackagePlan $package_plan)
    {
        if ($user->canDo('package_plan.package_plan.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
