<?php

namespace Litecms\PackagePlan\Providers;

use Illuminate\Support\ServiceProvider;

class PackagePlanServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'package_plan');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'package_plan');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.package_plan', function ($app) {
            return $this->app->make('Litecms\PackagePlan\PackagePlan');
        });

                // Bind PackagePlan to repository
        $this->app->bind(
            'Litecms\PackagePlan\Interfaces\PackagePlanRepositoryInterface',
            \Litecms\PackagePlan\Repositories\Eloquent\PackagePlanRepository::class
        );

        $this->app->register(\Litecms\PackagePlan\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\PackagePlan\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\PackagePlan\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.package_plan'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/package_plan.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/package_plan')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/package_plan')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
